@@ -250,7 +250,7 @@ static Type *get_type(const char *name, GError **error)
 			return type;
 	}
 
-	g_warning("Unknown media type in type '%s'\n", name);
+	g_warning("Unknown media type in type '%s'", name);
 
 	return type;
 }
@@ -685,7 +685,7 @@ static void load_source_file(const char *filename)
 	doc = xmlParseFile(filename);
 	if (!doc)
 	{
-		g_warning(_("Failed to parse '%s'\n"), filename);
+		g_warning(_("Failed to parse '%s'"), filename);
 		return;
 	}
 
@@ -693,16 +693,13 @@ static void load_source_file(const char *filename)
 
 	if (root->ns == NULL || xmlStrcmp(root->ns->href, FREE_NS) != 0)
 	{
-		g_warning("* Wrong namespace on document element\n"
-			  "*   in '%s'\n"
-			  "*   (should be %s)\n", filename, FREE_NS);
+		g_warning("Wrong namespace on document element in '%s' (should be %s)", filename, FREE_NS);
 		goto out;
 	}
-	
+
 	if (strcmp((char *)root->name, "mime-info") != 0)
 	{
-		g_warning("* Root element <%s> is not <mime-info>\n"
-			  "*   (in '%s')\n", root->name, filename);
+		g_warning("Root element <%s> is not <mime-info> (in '%s')", root->name, filename);
 		goto out;
 	}
 
@@ -746,9 +743,7 @@ static void load_source_file(const char *filename)
 
 		if (error)
 		{
-			g_warning("* Error in type '%s/%s'\n"
-				  "*   (in %s):\n"
-				  "*   %s.\n",
+			g_warning("Error in type '%s/%s' (in %s): %s.",
 				  type ? type->media : _("unknown"),
 				  type ? type->subtype : _("unknown"),
 				  filename, error->message);
@@ -855,8 +850,8 @@ static void write_out_glob(GList *globs, FILE *stream)
 		glob = (Glob *)list->data;
 		type = glob->type;
 		if (strchr(glob->pattern, '\n'))
-			g_warning("* Glob patterns can't contain literal newlines "
-				  "(%s in type %s/%s)\n", glob->pattern,
+			g_warning("Glob patterns can't contain literal newlines "
+				  "(%s in type %s/%s)", glob->pattern,
 				  type->media, type->subtype);
 		else
 			g_fprintf(stream, "%s/%s:%s\n",
@@ -876,10 +871,10 @@ static void write_out_glob2(GList *globs, FILE *stream)
 		glob = (Glob *)list->data;
 		type = glob->type;
 		if (strchr(glob->pattern, '\n'))
-			g_warning("* Glob patterns can't contain literal newlines "
-				  "(%s in type %s/%s)\n", glob->pattern,
+			g_warning("Glob patterns can't contain literal newlines "
+				  "(%s in type %s/%s)", glob->pattern,
 				  type->media, type->subtype);
-		else 
+		else
 		{
 			need_flags = FALSE;
 			if (glob->case_sensitive)
@@ -933,7 +928,7 @@ static void atomic_update(const gchar *pathname)
 	remove(new_name);
 #endif
 	if (rename(pathname, new_name))
-		g_warning("Failed to rename %s as %s , errno: %d\n", pathname, new_name, errno);
+		g_warning("Failed to rename %s as %s , errno: %d", pathname, new_name, errno);
 
 	g_free(new_name);
 }
@@ -955,9 +950,9 @@ static void write_out_type(gpointer key, gpointer value, gpointer data)
 	filename = g_strconcat(media, "/", type->subtype, ".xml.new", NULL);
 	g_free(media);
 	media = NULL;
-	
+
 	if (save_xml_file(type->output, filename) != 0)
-		g_warning("Failed to write out '%s'\n", filename);
+		g_warning("Failed to write out '%s'", filename);
 
 	atomic_update(filename);
 
@@ -1899,7 +1894,7 @@ static void delete_old_types(const gchar *mime_dir)
 				path = g_strconcat(mime_dir, "/",
 						type_name, ".xml", NULL);
 #if 0
-				g_warning("* Removing old info for type %s\n",
+				g_warning("Removing old info for type %s",
 						path);
 #endif
 				unlink(path);
@@ -2071,7 +2066,7 @@ static void check_in_path_xdg_data(const char *mime_path)
 	if (stat(path, &path_info))
 	{
 		g_warning("Can't stat '%s' directory: %s",
-				path, g_strerror(errno));
+			  path, g_strerror(errno));
 		goto out;
 	}
 
@@ -2100,11 +2095,11 @@ static void check_in_path_xdg_data(const char *mime_path)
 
 	if (i == n)
 	{
-		g_warning(_("\nNote that '%s' is not in the search path\n"
-			"set by the XDG_DATA_HOME and XDG_DATA_DIRS\n"
-			"environment variables, so applications may not\n"
-			"be able to find it until you set them. The\n"
-			"directories currently searched are:\n\n"), path);
+		g_printerr(_("\nNote that '%s' is not in the search path\n"
+			     "set by the XDG_DATA_HOME and XDG_DATA_DIRS\n"
+			     "environment variables, so applications may not\n"
+			     "be able to find it until you set them. The\n"
+			     "directories currently searched are:\n\n"), path);
 		g_printerr("- %s\n", dirs[n - 1]);
 		for (i = 0; i < n - 1; i++)
 			g_printerr("- %s\n", dirs[i]);
@@ -2251,8 +2246,8 @@ write_map_entry (gpointer key,
           offset = GPOINTER_TO_UINT (g_hash_table_lookup (map_data->pool, values[i]));
           if (offset == 0)
             {
-              g_warning ("Missing string: '%s'\n", values[i]);
-              map_data->error = TRUE;  
+              g_warning ("Missing string: '%s'", values[i]);
+              map_data->error = TRUE;
             }
           if (!write_card32 (map_data->cache, offset))
           map_data->error = TRUE;
@@ -2394,8 +2389,8 @@ write_parent_entry (gpointer key,
   offset = GPOINTER_TO_UINT (g_hash_table_lookup (map_data->pool, mimetype));
   if (offset == 0)
     {
-      g_warning ("Missing string: '%s'\n", (gchar *)key);
-      map_data->error = TRUE;  
+      g_warning ("Missing string: '%s'", (gchar *)key);
+      map_data->error = TRUE;
     }
 
   parents_offset = map_data->offset;
@@ -2427,8 +2422,8 @@ write_parent_list (gpointer key,
       offset = GPOINTER_TO_UINT (g_hash_table_lookup (map_data->pool, parent));
       if (offset == 0)
 	{
-	  g_warning ("Missing string: '%s'\n", parent);
-	  map_data->error = TRUE;  
+	  g_warning ("Missing string: '%s'", parent);
+	  map_data->error = TRUE;
 	}
       
       if (!write_card32 (map_data->cache, offset))
@@ -2664,7 +2659,7 @@ build_suffixes (gpointer key,
       
       if (suffix == NULL)
 	{
-	  g_warning ("Glob '%s' is not valid UTF-8\n", pattern);
+	  g_warning ("Glob '%s' is not valid UTF-8", pattern);
 	  return;
 	}
 
@@ -2731,7 +2726,7 @@ write_suffix_entries (FILE        *cache,
       offset = GPOINTER_TO_UINT(g_hash_table_lookup (strings, entry->mimetype));
       if (offset == 0)
 	{
-	  g_warning ("Missing string: '%s'\n", entry->mimetype);
+	  g_warning ("Missing string: '%s'", entry->mimetype);
 	  return FALSE;
 	}
     }
@@ -2839,7 +2834,7 @@ write_match (gpointer key,
   offset = GPOINTER_TO_UINT (g_hash_table_lookup (mdata->strings, mimetype));
   if (offset == 0)
     {
-      g_warning ("Missing string: '%s'\n", mimetype);
+      g_warning ("Missing string: '%s'", mimetype);
       g_free (mimetype);
       mdata->error = TRUE;
       return;
@@ -3307,7 +3302,7 @@ write_cache (FILE *cache)
   offset = 0;
   if (!write_header (cache, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &offset))
     {
-      g_warning ("Failed to write header\n");
+      g_warning ("Failed to write header");
       return FALSE;
     }
 
@@ -3317,7 +3312,7 @@ write_cache (FILE *cache)
 
   if (!write_strings (cache, strings, &offset))
     {
-      g_warning ("Failed to write strings\n");
+      g_warning ("Failed to write strings");
       return FALSE;
     }
   g_message ("Wrote %d strings at %x - %x\n", 
@@ -3326,7 +3321,7 @@ write_cache (FILE *cache)
   alias_offset = offset;
   if (!write_alias_cache (cache, strings, &offset))
     {
-      g_warning ("Failed to write alias list\n");
+      g_warning ("Failed to write alias list");
       return FALSE;
     }
   g_message ("Wrote aliases at %x - %x\n", alias_offset, offset);
@@ -3334,7 +3329,7 @@ write_cache (FILE *cache)
   parent_offset = offset;
   if (!write_parent_cache (cache, strings, &offset))
     {
-      g_warning ("Failed to write parent list\n");
+      g_warning ("Failed to write parent list");
       return FALSE;
     }
   g_message ("Wrote parents at %x - %x\n", parent_offset, offset);
@@ -3342,7 +3337,7 @@ write_cache (FILE *cache)
   literal_offset = offset;
   if (!write_literal_cache (cache, strings, &offset))
     {
-      g_warning ("Failed to write literal list\n");
+      g_warning ("Failed to write literal list");
       return FALSE;
     }
   g_message ("Wrote literal globs at %x - %x\n", literal_offset, offset);
@@ -3350,7 +3345,7 @@ write_cache (FILE *cache)
   suffix_offset = offset;
   if (!write_suffix_cache (cache, strings, &offset))
     {
-      g_warning ("Failed to write suffix list\n");
+      g_warning ("Failed to write suffix list");
       return FALSE;
     }
   g_message ("Wrote suffix globs at %x - %x\n", suffix_offset, offset);
@@ -3358,7 +3353,7 @@ write_cache (FILE *cache)
   glob_offset = offset;
   if (!write_glob_cache (cache, strings, &offset))
     {
-      g_warning ("Failed to write glob list\n");
+      g_warning ("Failed to write glob list");
       return FALSE;
     }
   g_message ("Wrote full globs at %x - %x\n", glob_offset, offset);
@@ -3366,7 +3361,7 @@ write_cache (FILE *cache)
   magic_offset = offset;
   if (!write_magic_cache (cache, strings, &offset))
     {
-      g_warning ("Failed to write magic list\n");
+      g_warning ("Failed to write magic list");
       return FALSE;
     }
   g_message ("Wrote magic at %x - %x\n", magic_offset, offset);
@@ -3374,7 +3369,7 @@ write_cache (FILE *cache)
   namespace_offset = offset;
   if (!write_namespace_cache (cache, strings, &offset))
     {
-      g_warning ("Failed to write namespace list\n");
+      g_warning ("Failed to write namespace list");
       return FALSE;
     }
   g_message ("Wrote namespace list at %x - %x\n", namespace_offset, offset);
@@ -3382,7 +3377,7 @@ write_cache (FILE *cache)
   icons_list_offset = offset;
   if (!write_icons_cache (cache, strings, icon_hash, &offset))
     {
-      g_warning ("Failed to write icons list\n");
+      g_warning ("Failed to write icons list");
       return FALSE;
     }
   g_message ("Wrote icons list at %x - %x\n", icons_list_offset, offset);
@@ -3390,7 +3385,7 @@ write_cache (FILE *cache)
   generic_icons_list_offset = offset;
   if (!write_icons_cache (cache, strings, generic_icon_hash, &offset))
     {
-      g_warning ("Failed to write generic icons list\n");
+      g_warning ("Failed to write generic icons list");
       return FALSE;
     }
   g_message ("Wrote generic icons list at %x - %x\n", generic_icons_list_offset, offset);
@@ -3398,7 +3393,7 @@ write_cache (FILE *cache)
   type_offset = offset;
   if (!write_types_cache (cache, strings, types, &offset))
     {
-      g_warning ("Failed to write types list\n");
+      g_warning ("Failed to write types list");
       return FALSE;
     }
   g_message ("Wrote types list at %x - %x\n", type_offset, offset);
@@ -3413,7 +3408,7 @@ write_cache (FILE *cache)
 		     generic_icons_list_offset, type_offset, 
 		     &offset))
     {
-      g_warning ("Failed to rewrite header\n");
+      g_warning ("Failed to rewrite header");
       return FALSE;
     }
 
@@ -3494,14 +3489,14 @@ int main(int argc, char **argv)
 
 	if (access(mime_dir, F_OK))
 	{
-		g_warning(_("Directory '%s' does not exist!\n"), package_dir);
+		g_warning(_("Directory '%s' does not exist!"), package_dir);
 		return EXIT_FAILURE;
 	}
 
 	if (access(mime_dir, W_OK))
 	{
-		g_warning(_("%s: I don't have write permission on %s.\n"
-			     "Try rerunning me as root.\n"), argv[0], mime_dir);
+		g_warning(_("%s: I don't have write permission on %s. "
+			     "Try rerunning me as root."), argv[0], mime_dir);
 		return EXIT_FAILURE;
 	}
 
